#
# spec file for package python3-pycparser
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pycparser
Version:        2.14
Release:        5.2
Summary:        C parser in Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/eliben/pycparser
Source:         http://pypi.python.org/packages/source/p/pycparser/pycparser-%{version}.tar.gz
BuildRequires:  python3
BuildRequires:  python3-devel
Requires:       python3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
pycparser is a complete parser of the C language, written in pure Python using
the PLY parsing library. It parses C code into an AST and can serve as a
front-end for C compilers or analysis tools.

%prep
%setup -q -n pycparser-%{version}
sed -i 's/\r$//' LICENSE

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python3 tests/all_tests.py

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst examples
%{python3_sitelib}/*

%changelog
* Mon Jun 15 2015 arun@gmx.de
- update to version 2.14:
  * Added CParser parameter to specify output directory for generated
    parsing tables (#84).
  * Removed lcc's cpp and its license from the distribution. Using
    lcc's cpp is no longer recommended, now that Clang has binary
    builds available for Windows.
* Mon May 25 2015 arun@gmx.de
- update to version 2.13:
  * Added support for offsetof() the way gcc implements it (special builtin
    that takes a type as an argument).
  * Added faked va_* macros (these are expected to come from stdarg.h)
  * Added a bunch more fake headers and typedefs to support parsing C projects
    like Git and SQLite without modifications to pycparser.
  * Added support for empty initializer lists (#79).
* Sat Apr 25 2015 arun@gmx.de
- specfile:
  * update copyright year
  * updated url
- update to version 2.12:
  * This is a fix release for 2.11; the memory optimization with
    __slots__ on Coord and AST nodes didn't take weakrefs into
    account, which broke cffi and its many dependents (iseue
    [#76]). Fixed by adding __weakref__ to __slots__.
- changes from version 2.11:
  * Add support for C99 6.5.3.7 p7 - qualifiers within array
    dimensions in function declarations. Started with issue #21
    (reported with initial patch by Robin Martinjak).
  * Issue #27: bug in handling of unified wstring literals.
  * Issue #28: fix coord reporting for 'for' loops.
  * Added "examples/using_gcc_E_libc.py" to demonstrate how "gcc
  - E" can be used instead of "cpp" for preprocessing.
  * Pull request #64: support keywords like const, volatile, restrict
    and static in dimensions in array declarations.
  * Reduce memory usage of AST nodes (issue #72).
  * Parsing order of nested pointer declarations fixed (issue #68).
* Wed Aug 27 2014 toddrme2178@gmail.com
- Fix rpmlint issues
* Tue Aug 26 2014 toddrme2178@gmail.com
- Update to version 2.10:
  - A number of improvements in the handling of typedef-name ambiguities,
    contributed by Sye van der Veen in GitHub issue #1:
  * Allow shadowing of types by identifiers in inner scopes.
  * Allow struct field names to reside in a separate namespace and have
    the same names as types.
  * Allow duplicate typedefs in some cases to mimic real compiler behavior.
  - c_generator error for ExprList in expression context.
  - Assume default int type for functions whose argument or return types were
    not specified.
  - Relax the lexer a bit w.r.t. some integer suffixes and $ in identifier names
    (which is supported by some other compilers).
- Package LICENSE
* Sat Apr 13 2013 toddrme2178@gmail.com
- Remove pre_checkin.sh since the two packages are not the same
* Fri Apr 12 2013 toddrme2178@gmail.com
- Added requires and buildrequires python3.  It will not work
  properly without them on openSUSE < 12.3
* Tue Mar 19 2013 speilicke@suse.com
- Drop some unneded macros
* Wed Feb 27 2013 p.drouand@gmail.com
- Initial python3 support
* Sun Feb 10 2013 saschpe@suse.de
- Initial version
